==> SCCS_1.2.tar.gz: SCCS/man/SCCS-package.Rd <==
\name{SCCS-package}
\alias{SCCS-package}
\alias{SCCS}
%\alias{ispline1}
%\alias{ispline2}
%\alias{ispline3}
\docType{package}
\title{The Self-Controlled Case Series (SCCS) Method
%%What the package does (short line)
%%~~ package title ~~
}
\description{Fits the self-controlled case series model used to investigate the association between a time-varying exposures such as vaccines or other drugs and an adverse event. Some extensions of the SCCS method can be fitted with this package.
%% More about what it does (maybe more than one line)
%% ~~ A concise (1-5 lines) description of the package ~~
}
\details{
\tabular{ll}{
Package: \tab SCCS\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2018-05-03\cr
License: \tab "GPL-2"\cr
}
%%~~ An overview of how to use the package, including the most ~~
%%~~ important functions ~~
}
\author{
Yonas Ghebremichael-Weldeselassie, Heather Whitaker, Paddy Farrington

Maintainer: Yonas Ghebremichael-Weldeselassie <y.weldeselassie@warwick.ac.uk>
%% ~~ The author and/or maintainer of the package ~~
}
\references{
\url{https://sccs-studies.info/index.html}

Farrington, P., Whitaker, H., and Ghebremichael-Weldeselassie, Y. (2018). Self-controlled Case Series Studies: A modelling Guide with R. Boca Raton: Chapman & Hall/CRC Press. 
}
%%~~ Optionally other standard keywords, one per line, from file %%~~
%%~~ KEYWORDS in the R documentation directory ~~
\keyword{ package }
%\seealso{
%~~ Optional links to other man pages, e.g. ~~
%~~ \code{\link[<pkg>:<pkg>-package]{<pkg>}} ~~}
%\examples{
%~~ simple examples of the most important functions ~~
%}

==> SCCS_1.4.tar.gz: SCCS/man/SCCS-package.Rd <==
\name{SCCS-package}
\alias{SCCS-package}
\alias{SCCS}
%\alias{ispline1}
%\alias{ispline2}
%\alias{ispline3}
\docType{package}
\title{The Self-Controlled Case Series (SCCS) Method
%%What the package does (short line)
%%~~ package title ~~
}
\description{Fits the self-controlled case series model used to investigate the association between a time-varying exposures such as vaccines or other drugs and an adverse event. Some extensions of the SCCS method can be fitted with this package.

Note: Ages and times describing the start and end of observation, exposure times, and event times, should be expressed as integers. In most of the datasets, units of time are days; other choices may be appropriate according to context, but must be given as integers. Ages appearing as covariates need not be integers.
%% More about what it does (maybe more than one line)
%% ~~ A concise (1-5 lines) description of the package ~~
}
\details{
\tabular{ll}{
Package: \tab SCCS\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2018-05-03\cr
License: \tab "GPL-2"\cr
}
%%~~ An overview of how to use the package, including the most ~~
%%~~ important functions ~~
}
\author{
Yonas Ghebremichael-Weldeselassie, Heather Whitaker, Paddy Farrington

Maintainer: Yonas Ghebremichael-Weldeselassie <y.weldeselassie@warwick.ac.uk>
%% ~~ The author and/or maintainer of the package ~~
}
\references{
\url{https://sccs-studies.info/index.html}

Farrington, P., Whitaker, H., and Ghebremichael-Weldeselassie, Y. (2018). Self-controlled Case Series Studies: A modelling Guide with R. Boca Raton: Chapman & Hall/CRC Press. 
}
%%~~ Optionally other standard keywords, one per line, from file %%~~
%%~~ KEYWORDS in the R documentation directory ~~
\keyword{ package }
%\seealso{
%~~ Optional links to other man pages, e.g. ~~
%~~ \code{\link[<pkg>:<pkg>-package]{<pkg>}} ~~}
%\examples{
%~~ simple examples of the most important functions ~~
%}
